summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/hierarchicalcodeblock.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/hierarchicalcodeblock.cpp')
-rw-r--r--umbrello/umbrello/hierarchicalcodeblock.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/umbrello/umbrello/hierarchicalcodeblock.cpp b/umbrello/umbrello/hierarchicalcodeblock.cpp
index 73e59bab..8802cbcf 100644
--- a/umbrello/umbrello/hierarchicalcodeblock.cpp
+++ b/umbrello/umbrello/hierarchicalcodeblock.cpp
@@ -114,7 +114,7 @@ bool HierarchicalCodeBlock::insertTextBlock(TextBlock * newBlock, TextBlock * ex
return false;
TQString tag = existingBlock->getTag();
// FIX: just do a quick check if the tqparent DOCUMENT has this.
// IF it does, then the lack of an index will force us into
// a search of any child hierarchical codeblocks we may have
// Its not efficient, but works. I don't think speed is a problem
@@ -365,7 +365,7 @@ TextBlock * HierarchicalCodeBlock::findCodeClassFieldTextBlockByTag ( const TQSt
if(cdoc)
return cdoc->findCodeClassFieldTextBlockByTag(tag);
else
- kError()<<" HierarchicalCodeBlock: findCodeClassFieldTextBlockByTag() finds NO tqparent document! Badly constructed textblock?!?"<<endl;
+ kError()<<" HierarchicalCodeBlock: findCodeClassFieldTextBlockByTag() finds NO parent document! Badly constructed textblock?!?"<<endl;
// if we get here, we failed.
return (TextBlock*) NULL;
@@ -114,7 +114,7 @@ bool HierarchicalCodeBlock::insertTextBlock(TextBlock * newBlock, TextBlock * ex
return false;
TQString tag = existingBlock->getTag();
- // FIX: just do a quick check if the tqparent DOCUMENT has this.
+ // FIX: just do a quick check if the parent DOCUMENT has this.
// IF it does, then the lack of an index will force us into
// a search of any child hierarchical codeblocks we may have